OC.L10N.register(
    "notes",
    {
    "Notes" : "Notes",
    "Error" : "Greška",
    "New note" : "Nova beleška",
    "Display mode for notes" : "Režim prikaza beleški",
    "Open in edit mode" : "Otvori u režimu uređivanja",
    "Open in preview mode" : "Otvori u režimu pregleda",
    "No notes yet" : "Još nema beleški",
    "All notes" : "Sve beleške",
    "Today" : "Today",
    "Yesterday" : "juče",
    "This week" : "Ove sedmice",
    "Last week" : "Prošle nedelje",
    "This month" : "Ovog meseca",
    "Last month" : "Prošlog meseca",
    "Rename" : "Preimenuj",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Details" : "Detalji",
    "Edit" : "Uredi",
    "Preview" : "Pregled",
    "Category" : "Kategorija",
    "Uncategorized" : "Nekategorizovano"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
